from setuptools import setup

setup(
    name='simplePackage2',
    version='0.1.0',    
    description='A example package',
    author='Alexey',
    author_email='ashik2001@yandex.ru',
    url='https://www.google.com',
    packages=['simplePackage2'],
    install_requires=['numpy==1.21.0'],
)